@@ -17,12 +17,13 @@ import warnings
 import numpy as np
 
 from . import empirical_covariance, EmpiricalCovariance
+from .._config import config_context
 from ..utils import check_array
-from ..utils.validation import _deprecate_positional_args
 
 
 # ShrunkCovariance estimator
 
+
 def shrunk_covariance(emp_cov, shrinkage=0.1):
     """Calculates a covariance matrix shrunk on the diagonal
 
@@ -54,21 +55,21 @@ def shrunk_covariance(emp_cov, shrinkage=0.1):
     n_features = emp_cov.shape[0]
 
     mu = np.trace(emp_cov) / n_features
-    shrunk_cov = (1. - shrinkage) * emp_cov
-    shrunk_cov.flat[::n_features + 1] += shrinkage * mu
+    shrunk_cov = (1.0 - shrinkage) * emp_cov
+    shrunk_cov.flat[:: n_features + 1] += shrinkage * mu
 
     return shrunk_cov
 
 
 class ShrunkCovariance(EmpiricalCovariance):
-    """Covariance estimator with shrinkage
+    """Covariance estimator with shrinkage.
 
     Read more in the :ref:`User Guide <shrunk_covariance>`.
 
     Parameters
     ----------
     store_precision : bool, default=True
-        Specify if the estimated precision is stored
+        Specify if the estimated precision is stored.
 
     assume_centered : bool, default=False
         If True, data will not be centered before computation.
@@ -92,6 +93,39 @@ class ShrunkCovariance(EmpiricalCovariance):
         Estimated pseudo inverse matrix.
         (stored only if store_precision is True)
 
+    n_features_in_ : int
+        Number of features seen during :term:`fit`.
+
+        .. versionadded:: 0.24
+
+    feature_names_in_ : ndarray of shape (`n_features_in_`,)
+        Names of features seen during :term:`fit`. Defined only when `X`
+        has feature names that are all strings.
+
+        .. versionadded:: 1.0
+
+    See Also
+    --------
+    EllipticEnvelope : An object for detecting outliers in
+        a Gaussian distributed dataset.
+    EmpiricalCovariance : Maximum likelihood covariance estimator.
+    GraphicalLasso : Sparse inverse covariance estimation
+        with an l1-penalized estimator.
+    GraphicalLassoCV : Sparse inverse covariance with cross-validated
+        choice of the l1 penalty.
+    LedoitWolf : LedoitWolf Estimator.
+    MinCovDet : Minimum Covariance Determinant
+        (robust estimator of covariance).
+    OAS : Oracle Approximating Shrinkage Estimator.
+
+    Notes
+    -----
+    The regularized covariance is given by:
+
+    (1 - shrinkage) * cov + shrinkage * mu * np.identity(n_features)
+
+    where mu = trace(cov) / n_features
+
     Examples
     --------
     >>> import numpy as np
@@ -109,38 +143,30 @@ class ShrunkCovariance(EmpiricalCovariance):
            [0.2536..., 0.4110...]])
     >>> cov.location_
     array([0.0622..., 0.0193...])
-
-    Notes
-    -----
-    The regularized covariance is given by:
-
-    (1 - shrinkage) * cov + shrinkage * mu * np.identity(n_features)
-
-    where mu = trace(cov) / n_features
     """
-    @_deprecate_positional_args
-    def __init__(self, *, store_precision=True, assume_centered=False,
-                 shrinkage=0.1):
-        super().__init__(store_precision=store_precision,
-                         assume_centered=assume_centered)
+
+    def __init__(self, *, store_precision=True, assume_centered=False, shrinkage=0.1):
+        super().__init__(
+            store_precision=store_precision, assume_centered=assume_centered
+        )
         self.shrinkage = shrinkage
 
     def fit(self, X, y=None):
-        """Fit the shrunk covariance model according to the given training data
-        and parameters.
+        """Fit the shrunk covariance model to X.
 
         Parameters
         ----------
         X : array-like of shape (n_samples, n_features)
-            Training data, where n_samples is the number of samples
-            and n_features is the number of features.
+            Training data, where `n_samples` is the number of samples
+            and `n_features` is the number of features.
 
-        y: Ignored
-            not used, present for API consistence purpose.
+        y : Ignored
+            Not used, present for API consistency by convention.
 
         Returns
         -------
         self : object
+            Returns the instance itself.
         """
         X = self._validate_data(X)
         # Not calling the parent object to fit, to avoid a potential
@@ -149,8 +175,7 @@ class ShrunkCovariance(EmpiricalCovariance):
             self.location_ = np.zeros(X.shape[1])
         else:
             self.location_ = X.mean(0)
-        covariance = empirical_covariance(
-            X, assume_centered=self.assume_centered)
+        covariance = empirical_covariance(X, assume_centered=self.assume_centered)
         covariance = shrunk_covariance(covariance, self.shrinkage)
         self._set_covariance(covariance)
 
@@ -159,6 +184,7 @@ class ShrunkCovariance(EmpiricalCovariance):
 
 # Ledoit-Wolf estimator
 
+
 def ledoit_wolf_shrinkage(X, assume_centered=False, block_size=1000):
     """Estimates the shrunk Ledoit-Wolf covariance matrix.
 
@@ -176,7 +202,7 @@ def ledoit_wolf_shrinkage(X, assume_centered=False, block_size=1000):
         If False, data will be centered before computation.
 
     block_size : int, default=1000
-        Size of the blocks into which the covariance matrix will be split.
+        Size of blocks into which the covariance matrix will be split.
 
     Returns
     -------
@@ -192,16 +218,17 @@ def ledoit_wolf_shrinkage(X, assume_centered=False, block_size=1000):
 
     where mu = trace(cov) / n_features
     """
-    X = np.asarray(X)
+    X = check_array(X)
     # for only one feature, the result is the same whatever the shrinkage
     if len(X.shape) == 2 and X.shape[1] == 1:
-        return 0.
+        return 0.0
     if X.ndim == 1:
         X = np.reshape(X, (1, -1))
 
     if X.shape[0] == 1:
-        warnings.warn("Only one sample available. "
-                      "You may want to reshape your data array")
+        warnings.warn(
+            "Only one sample available. You may want to reshape your data array"
+        )
     n_samples, n_features = X.shape
 
     # optionally center data
@@ -216,8 +243,8 @@ def ledoit_wolf_shrinkage(X, assume_centered=False, block_size=1000):
     X2 = X ** 2
     emp_cov_trace = np.sum(X2, axis=0) / n_samples
     mu = np.sum(emp_cov_trace) / n_features
-    beta_ = 0.  # sum of the coefficients of <X2.T, X2>
-    delta_ = 0.  # sum of the *squared* coefficients of <X.T, X>
+    beta_ = 0.0  # sum of the coefficients of <X2.T, X2>
+    delta_ = 0.0  # sum of the *squared* coefficients of <X.T, X>
     # starting block computation
     for i in range(n_splits):
         for j in range(n_splits):
@@ -226,26 +253,26 @@ def ledoit_wolf_shrinkage(X, assume_centered=False, block_size=1000):
             beta_ += np.sum(np.dot(X2.T[rows], X2[:, cols]))
             delta_ += np.sum(np.dot(X.T[rows], X[:, cols]) ** 2)
         rows = slice(block_size * i, block_size * (i + 1))
-        beta_ += np.sum(np.dot(X2.T[rows], X2[:, block_size * n_splits:]))
-        delta_ += np.sum(
-            np.dot(X.T[rows], X[:, block_size * n_splits:]) ** 2)
+        beta_ += np.sum(np.dot(X2.T[rows], X2[:, block_size * n_splits :]))
+        delta_ += np.sum(np.dot(X.T[rows], X[:, block_size * n_splits :]) ** 2)
     for j in range(n_splits):
         cols = slice(block_size * j, block_size * (j + 1))
-        beta_ += np.sum(np.dot(X2.T[block_size * n_splits:], X2[:, cols]))
-        delta_ += np.sum(
-            np.dot(X.T[block_size * n_splits:], X[:, cols]) ** 2)
-    delta_ += np.sum(np.dot(X.T[block_size * n_splits:],
-                            X[:, block_size * n_splits:]) ** 2)
+        beta_ += np.sum(np.dot(X2.T[block_size * n_splits :], X2[:, cols]))
+        delta_ += np.sum(np.dot(X.T[block_size * n_splits :], X[:, cols]) ** 2)
+    delta_ += np.sum(
+        np.dot(X.T[block_size * n_splits :], X[:, block_size * n_splits :]) ** 2
+    )
     delta_ /= n_samples ** 2
-    beta_ += np.sum(np.dot(X2.T[block_size * n_splits:],
-                           X2[:, block_size * n_splits:]))
+    beta_ += np.sum(
+        np.dot(X2.T[block_size * n_splits :], X2[:, block_size * n_splits :])
+    )
     # use delta_ to compute beta
-    beta = 1. / (n_features * n_samples) * (beta_ / n_samples - delta_)
+    beta = 1.0 / (n_features * n_samples) * (beta_ / n_samples - delta_)
     # delta is the sum of the squared coefficients of (<X.T,X> - mu*Id) / p
-    delta = delta_ - 2. * mu * emp_cov_trace.sum() + n_features * mu ** 2
+    delta = delta_ - 2.0 * mu * emp_cov_trace.sum() + n_features * mu ** 2
     delta /= n_features
     # get final beta as the min between beta and delta
-    # We do this to prevent shrinking more than "1", which whould invert
+    # We do this to prevent shrinking more than "1", which would invert
     # the value of covariances
     beta = min(beta, delta)
     # finally get shrinkage
@@ -253,7 +280,6 @@ def ledoit_wolf_shrinkage(X, assume_centered=False, block_size=1000):
     return shrinkage
 
 
-@_deprecate_positional_args
 def ledoit_wolf(X, *, assume_centered=False, block_size=1000):
     """Estimates the shrunk Ledoit-Wolf covariance matrix.
 
@@ -271,7 +297,7 @@ def ledoit_wolf(X, *, assume_centered=False, block_size=1000):
         If False, data will be centered before computation.
 
     block_size : int, default=1000
-        Size of the blocks into which the covariance matrix will be split.
+        Size of blocks into which the covariance matrix will be split.
         This is purely a memory optimization and does not affect results.
 
     Returns
@@ -291,33 +317,35 @@ def ledoit_wolf(X, *, assume_centered=False, block_size=1000):
 
     where mu = trace(cov) / n_features
     """
-    X = np.asarray(X)
+    X = check_array(X)
     # for only one feature, the result is the same whatever the shrinkage
     if len(X.shape) == 2 and X.shape[1] == 1:
         if not assume_centered:
             X = X - X.mean()
-        return np.atleast_2d((X ** 2).mean()), 0.
+        return np.atleast_2d((X ** 2).mean()), 0.0
     if X.ndim == 1:
         X = np.reshape(X, (1, -1))
-        warnings.warn("Only one sample available. "
-                      "You may want to reshape your data array")
+        warnings.warn(
+            "Only one sample available. You may want to reshape your data array"
+        )
         n_features = X.size
     else:
         _, n_features = X.shape
 
     # get Ledoit-Wolf shrinkage
     shrinkage = ledoit_wolf_shrinkage(
-        X, assume_centered=assume_centered, block_size=block_size)
+        X, assume_centered=assume_centered, block_size=block_size
+    )
     emp_cov = empirical_covariance(X, assume_centered=assume_centered)
     mu = np.sum(np.trace(emp_cov)) / n_features
-    shrunk_cov = (1. - shrinkage) * emp_cov
-    shrunk_cov.flat[::n_features + 1] += shrinkage * mu
+    shrunk_cov = (1.0 - shrinkage) * emp_cov
+    shrunk_cov.flat[:: n_features + 1] += shrinkage * mu
 
     return shrunk_cov, shrinkage
 
 
 class LedoitWolf(EmpiricalCovariance):
-    """LedoitWolf Estimator
+    """LedoitWolf Estimator.
 
     Ledoit-Wolf is a particular form of shrinkage, where the shrinkage
     coefficient is computed using O. Ledoit and M. Wolf's formula as
@@ -339,7 +367,7 @@ class LedoitWolf(EmpiricalCovariance):
         If False (default), data will be centered before computation.
 
     block_size : int, default=1000
-        Size of the blocks into which the covariance matrix will be split
+        Size of blocks into which the covariance matrix will be split
         during its Ledoit-Wolf estimation. This is purely a memory
         optimization and does not affect results.
 
@@ -359,6 +387,46 @@ class LedoitWolf(EmpiricalCovariance):
         Coefficient in the convex combination used for the computation
         of the shrunk estimate. Range is [0, 1].
 
+    n_features_in_ : int
+        Number of features seen during :term:`fit`.
+
+        .. versionadded:: 0.24
+
+    feature_names_in_ : ndarray of shape (`n_features_in_`,)
+        Names of features seen during :term:`fit`. Defined only when `X`
+        has feature names that are all strings.
+
+        .. versionadded:: 1.0
+
+    See Also
+    --------
+    EllipticEnvelope : An object for detecting outliers in
+        a Gaussian distributed dataset.
+    EmpiricalCovariance : Maximum likelihood covariance estimator.
+    GraphicalLasso : Sparse inverse covariance estimation
+        with an l1-penalized estimator.
+    GraphicalLassoCV : Sparse inverse covariance with cross-validated
+        choice of the l1 penalty.
+    MinCovDet : Minimum Covariance Determinant
+        (robust estimator of covariance).
+    OAS : Oracle Approximating Shrinkage Estimator.
+    ShrunkCovariance : Covariance estimator with shrinkage.
+
+    Notes
+    -----
+    The regularised covariance is:
+
+    (1 - shrinkage) * cov + shrinkage * mu * np.identity(n_features)
+
+    where mu = trace(cov) / n_features
+    and shrinkage is given by the Ledoit and Wolf formula (see References)
+
+    References
+    ----------
+    "A Well-Conditioned Estimator for Large-Dimensional Covariance Matrices",
+    Ledoit and Wolf, Journal of Multivariate Analysis, Volume 88, Issue 2,
+    February 2004, pages 365-411.
+
     Examples
     --------
     >>> import numpy as np
@@ -375,32 +443,16 @@ class LedoitWolf(EmpiricalCovariance):
            [0.1616..., 0.8022...]])
     >>> cov.location_
     array([ 0.0595... , -0.0075...])
-
-    Notes
-    -----
-    The regularised covariance is:
-
-    (1 - shrinkage) * cov + shrinkage * mu * np.identity(n_features)
-
-    where mu = trace(cov) / n_features
-    and shrinkage is given by the Ledoit and Wolf formula (see References)
-
-    References
-    ----------
-    "A Well-Conditioned Estimator for Large-Dimensional Covariance Matrices",
-    Ledoit and Wolf, Journal of Multivariate Analysis, Volume 88, Issue 2,
-    February 2004, pages 365-411.
     """
-    @_deprecate_positional_args
-    def __init__(self, *, store_precision=True, assume_centered=False,
-                 block_size=1000):
-        super().__init__(store_precision=store_precision,
-                         assume_centered=assume_centered)
+
+    def __init__(self, *, store_precision=True, assume_centered=False, block_size=1000):
+        super().__init__(
+            store_precision=store_precision, assume_centered=assume_centered
+        )
         self.block_size = block_size
 
     def fit(self, X, y=None):
-        """Fit the Ledoit-Wolf shrunk covariance model according to the given
-        training data and parameters.
+        """Fit the Ledoit-Wolf shrunk covariance model to X.
 
         Parameters
         ----------
@@ -408,11 +460,12 @@ class LedoitWolf(EmpiricalCovariance):
             Training data, where `n_samples` is the number of samples
             and `n_features` is the number of features.
         y : Ignored
-            not used, present for API consistence purpose.
+            Not used, present for API consistency by convention.
 
         Returns
         -------
         self : object
+            Returns the instance itself.
         """
         # Not calling the parent object to fit, to avoid computing the
         # covariance matrix (and potentially the precision)
@@ -421,9 +474,10 @@ class LedoitWolf(EmpiricalCovariance):
             self.location_ = np.zeros(X.shape[1])
         else:
             self.location_ = X.mean(0)
-        covariance, shrinkage = ledoit_wolf(X - self.location_,
-                                            assume_centered=True,
-                                            block_size=self.block_size)
+        with config_context(assume_finite=True):
+            covariance, shrinkage = ledoit_wolf(
+                X - self.location_, assume_centered=True, block_size=self.block_size
+            )
         self.shrinkage_ = shrinkage
         self._set_covariance(covariance)
 
@@ -431,7 +485,6 @@ class LedoitWolf(EmpiricalCovariance):
 
 
 # OAS estimator
-@_deprecate_positional_args
 def oas(X, *, assume_centered=False):
     """Estimate covariance with the Oracle Approximating Shrinkage algorithm.
 
@@ -471,11 +524,12 @@ def oas(X, *, assume_centered=False):
     if len(X.shape) == 2 and X.shape[1] == 1:
         if not assume_centered:
             X = X - X.mean()
-        return np.atleast_2d((X ** 2).mean()), 0.
+        return np.atleast_2d((X ** 2).mean()), 0.0
     if X.ndim == 1:
         X = np.reshape(X, (1, -1))
-        warnings.warn("Only one sample available. "
-                      "You may want to reshape your data array")
+        warnings.warn(
+            "Only one sample available. You may want to reshape your data array"
+        )
         n_samples = 1
         n_features = X.size
     else:
@@ -487,17 +541,17 @@ def oas(X, *, assume_centered=False):
     # formula from Chen et al.'s **implementation**
     alpha = np.mean(emp_cov ** 2)
     num = alpha + mu ** 2
-    den = (n_samples + 1.) * (alpha - (mu ** 2) / n_features)
+    den = (n_samples + 1.0) * (alpha - (mu ** 2) / n_features)
 
-    shrinkage = 1. if den == 0 else min(num / den, 1.)
-    shrunk_cov = (1. - shrinkage) * emp_cov
-    shrunk_cov.flat[::n_features + 1] += shrinkage * mu
+    shrinkage = 1.0 if den == 0 else min(num / den, 1.0)
+    shrunk_cov = (1.0 - shrinkage) * emp_cov
+    shrunk_cov.flat[:: n_features + 1] += shrinkage * mu
 
     return shrunk_cov, shrinkage
 
 
 class OAS(EmpiricalCovariance):
-    """Oracle Approximating Shrinkage Estimator
+    """Oracle Approximating Shrinkage Estimator.
 
     Read more in the :ref:`User Guide <shrunk_covariance>`.
 
@@ -538,6 +592,45 @@ class OAS(EmpiricalCovariance):
       coefficient in the convex combination used for the computation
       of the shrunk estimate. Range is [0, 1].
 
+    n_features_in_ : int
+        Number of features seen during :term:`fit`.
+
+        .. versionadded:: 0.24
+
+    feature_names_in_ : ndarray of shape (`n_features_in_`,)
+        Names of features seen during :term:`fit`. Defined only when `X`
+        has feature names that are all strings.
+
+        .. versionadded:: 1.0
+
+    See Also
+    --------
+    EllipticEnvelope : An object for detecting outliers in
+        a Gaussian distributed dataset.
+    EmpiricalCovariance : Maximum likelihood covariance estimator.
+    GraphicalLasso : Sparse inverse covariance estimation
+        with an l1-penalized estimator.
+    GraphicalLassoCV : Sparse inverse covariance with cross-validated
+        choice of the l1 penalty.
+    LedoitWolf : LedoitWolf Estimator.
+    MinCovDet : Minimum Covariance Determinant
+        (robust estimator of covariance).
+    ShrunkCovariance : Covariance estimator with shrinkage.
+
+    Notes
+    -----
+    The regularised covariance is:
+
+    (1 - shrinkage) * cov + shrinkage * mu * np.identity(n_features)
+
+    where mu = trace(cov) / n_features
+    and shrinkage is given by the OAS formula (see References)
+
+    References
+    ----------
+    "Shrinkage Algorithms for MMSE Covariance Estimation"
+    Chen et al., IEEE Trans. on Sign. Proc., Volume 58, Issue 10, October 2010.
+
     Examples
     --------
     >>> import numpy as np
@@ -558,25 +651,10 @@ class OAS(EmpiricalCovariance):
            [-1.2431...,  3.3889...]])
     >>> oas.shrinkage_
     0.0195...
-
-    Notes
-    -----
-    The regularised covariance is:
-
-    (1 - shrinkage) * cov + shrinkage * mu * np.identity(n_features)
-
-    where mu = trace(cov) / n_features
-    and shrinkage is given by the OAS formula (see References)
-
-    References
-    ----------
-    "Shrinkage Algorithms for MMSE Covariance Estimation"
-    Chen et al., IEEE Trans. on Sign. Proc., Volume 58, Issue 10, October 2010.
     """
 
     def fit(self, X, y=None):
-        """Fit the Oracle Approximating Shrinkage covariance model
-        according to the given training data and parameters.
+        """Fit the Oracle Approximating Shrinkage covariance model to X.
 
         Parameters
         ----------
@@ -584,11 +662,12 @@ class OAS(EmpiricalCovariance):
             Training data, where `n_samples` is the number of samples
             and `n_features` is the number of features.
         y : Ignored
-            not used, present for API consistence purpose.
+            Not used, present for API consistency by convention.
 
         Returns
         -------
         self : object
+            Returns the instance itself.
         """
         X = self._validate_data(X)
         # Not calling the parent object to fit, to avoid computing the
