@@ -27,8 +27,6 @@ from sklearn.linear_model import LinearRegression
 from sklearn.svm import LinearSVC
 from sklearn.svm import LinearSVR
 from sklearn.svm import SVC
-from sklearn.tree import DecisionTreeClassifier
-from sklearn.tree import DecisionTreeRegressor
 from sklearn.ensemble import RandomForestClassifier
 from sklearn.ensemble import RandomForestRegressor
 from sklearn.preprocessing import scale
@@ -44,8 +42,6 @@ from sklearn.utils._mocking import CheckingClassifier
 from sklearn.utils._testing import assert_allclose
 from sklearn.utils._testing import assert_allclose_dense_sparse
 from sklearn.utils._testing import ignore_warnings
-from sklearn.utils.estimator_checks import check_estimator
-from sklearn.utils.estimator_checks import check_no_attributes_set_in_init
 
 X_diabetes, y_diabetes = load_diabetes(return_X_y=True)
 X_iris, y_iris = load_iris(return_X_y=True)
@@ -64,10 +60,12 @@ def test_stacking_classifier_iris(cv, final_estimator, passthrough):
     X_train, X_test, y_train, y_test = train_test_split(
         scale(X_iris), y_iris, stratify=y_iris, random_state=42
     )
-    estimators = [('lr', LogisticRegression()), ('svc', LinearSVC())]
+    estimators = [("lr", LogisticRegression()), ("svc", LinearSVC())]
     clf = StackingClassifier(
-        estimators=estimators, final_estimator=final_estimator, cv=cv,
-        passthrough=passthrough
+        estimators=estimators,
+        final_estimator=final_estimator,
+        cv=cv,
+        passthrough=passthrough,
     )
     clf.fit(X_train, y_train)
     clf.predict(X_test)
@@ -80,7 +78,7 @@ def test_stacking_classifier_iris(cv, final_estimator, passthrough):
     if passthrough:
         assert_allclose(X_test, X_trans[:, -4:])
 
-    clf.set_params(lr='drop')
+    clf.set_params(lr="drop")
     clf.fit(X_train, y_train)
     clf.predict(X_test)
     clf.predict_proba(X_test)
@@ -103,8 +101,10 @@ def test_stacking_classifier_drop_column_binary_classification():
     )
 
     # both classifiers implement 'predict_proba' and will both drop one column
-    estimators = [('lr', LogisticRegression()),
-                  ('rf', RandomForestClassifier(random_state=42))]
+    estimators = [
+        ("lr", LogisticRegression()),
+        ("rf", RandomForestClassifier(random_state=42)),
+    ]
     clf = StackingClassifier(estimators=estimators, cv=3)
 
     clf.fit(X_train, y_train)
@@ -112,7 +112,7 @@ def test_stacking_classifier_drop_column_binary_classification():
     assert X_trans.shape[1] == 2
 
     # LinearSVC does not implement 'predict_proba' and will not drop one column
-    estimators = [('lr', LogisticRegression()), ('svc', LinearSVC())]
+    estimators = [("lr", LogisticRegression()), ("svc", LinearSVC())]
     clf.set_params(estimators=estimators)
 
     clf.fit(X_train, y_train)
@@ -126,15 +126,12 @@ def test_stacking_classifier_drop_estimator():
     X_train, X_test, y_train, _ = train_test_split(
         scale(X_iris), y_iris, stratify=y_iris, random_state=42
     )
-    estimators = [('lr', 'drop'), ('svc', LinearSVC(random_state=0))]
+    estimators = [("lr", "drop"), ("svc", LinearSVC(random_state=0))]
     rf = RandomForestClassifier(n_estimators=10, random_state=42)
     clf = StackingClassifier(
-        estimators=[('svc', LinearSVC(random_state=0))],
-        final_estimator=rf, cv=5
-    )
-    clf_drop = StackingClassifier(
-        estimators=estimators, final_estimator=rf, cv=5
+        estimators=[("svc", LinearSVC(random_state=0))], final_estimator=rf, cv=5
     )
+    clf_drop = StackingClassifier(estimators=estimators, final_estimator=rf, cv=5)
 
     clf.fit(X_train, y_train)
     clf_drop.fit(X_train, y_train)
@@ -149,15 +146,12 @@ def test_stacking_regressor_drop_estimator():
     X_train, X_test, y_train, _ = train_test_split(
         scale(X_diabetes), y_diabetes, random_state=42
     )
-    estimators = [('lr', 'drop'), ('svr', LinearSVR(random_state=0))]
+    estimators = [("lr", "drop"), ("svr", LinearSVR(random_state=0))]
     rf = RandomForestRegressor(n_estimators=10, random_state=42)
     reg = StackingRegressor(
-        estimators=[('svr', LinearSVR(random_state=0))],
-        final_estimator=rf, cv=5
-    )
-    reg_drop = StackingRegressor(
-        estimators=estimators, final_estimator=rf, cv=5
+        estimators=[("svr", LinearSVR(random_state=0))], final_estimator=rf, cv=5
     )
+    reg_drop = StackingRegressor(estimators=estimators, final_estimator=rf, cv=5)
 
     reg.fit(X_train, y_train)
     reg_drop.fit(X_train, y_train)
@@ -165,27 +159,28 @@ def test_stacking_regressor_drop_estimator():
     assert_allclose(reg.transform(X_test), reg_drop.transform(X_test))
 
 
-@pytest.mark.parametrize(
-    "cv", [3, KFold(n_splits=3, shuffle=True, random_state=42)]
-)
+@pytest.mark.parametrize("cv", [3, KFold(n_splits=3, shuffle=True, random_state=42)])
 @pytest.mark.parametrize(
     "final_estimator, predict_params",
-    [(None, {}),
-     (RandomForestRegressor(random_state=42), {}),
-     (DummyRegressor(), {'return_std': True})]
+    [
+        (None, {}),
+        (RandomForestRegressor(random_state=42), {}),
+        (DummyRegressor(), {"return_std": True}),
+    ],
 )
 @pytest.mark.parametrize("passthrough", [False, True])
-def test_stacking_regressor_diabetes(cv, final_estimator, predict_params,
-                                     passthrough):
+def test_stacking_regressor_diabetes(cv, final_estimator, predict_params, passthrough):
     # prescale the data to avoid convergence warning without using a pipeline
     # for later assert
     X_train, X_test, y_train, _ = train_test_split(
         scale(X_diabetes), y_diabetes, random_state=42
     )
-    estimators = [('lr', LinearRegression()), ('svr', LinearSVR())]
+    estimators = [("lr", LinearRegression()), ("svr", LinearSVR())]
     reg = StackingRegressor(
-        estimators=estimators, final_estimator=final_estimator, cv=cv,
-        passthrough=passthrough
+        estimators=estimators,
+        final_estimator=final_estimator,
+        cv=cv,
+        passthrough=passthrough,
     )
     reg.fit(X_train, y_train)
     result = reg.predict(X_test, **predict_params)
@@ -199,7 +194,7 @@ def test_stacking_regressor_diabetes(cv, final_estimator, predict_params,
     if passthrough:
         assert_allclose(X_test, X_trans[:, -10:])
 
-    reg.set_params(lr='drop')
+    reg.set_params(lr="drop")
     reg.fit(X_train, y_train)
     reg.predict(X_test)
 
@@ -210,14 +205,13 @@ def test_stacking_regressor_diabetes(cv, final_estimator, predict_params,
         assert_allclose(X_test, X_trans[:, -10:])
 
 
-@pytest.mark.parametrize('fmt', ['csc', 'csr', 'coo'])
+@pytest.mark.parametrize("fmt", ["csc", "csr", "coo"])
 def test_stacking_regressor_sparse_passthrough(fmt):
     # Check passthrough behavior on a sparse X matrix
     X_train, X_test, y_train, _ = train_test_split(
-        sparse.coo_matrix(scale(X_diabetes)).asformat(fmt),
-        y_diabetes, random_state=42
+        sparse.coo_matrix(scale(X_diabetes)).asformat(fmt), y_diabetes, random_state=42
     )
-    estimators = [('lr', LinearRegression()), ('svr', LinearSVR())]
+    estimators = [("lr", LinearRegression()), ("svr", LinearSVR())]
     rf = RandomForestRegressor(n_estimators=10, random_state=42)
     clf = StackingRegressor(
         estimators=estimators, final_estimator=rf, cv=5, passthrough=True
@@ -229,14 +223,13 @@ def test_stacking_regressor_sparse_passthrough(fmt):
     assert X_test.format == X_trans.format
 
 
-@pytest.mark.parametrize('fmt', ['csc', 'csr', 'coo'])
+@pytest.mark.parametrize("fmt", ["csc", "csr", "coo"])
 def test_stacking_classifier_sparse_passthrough(fmt):
     # Check passthrough behavior on a sparse X matrix
     X_train, X_test, y_train, _ = train_test_split(
-        sparse.coo_matrix(scale(X_iris)).asformat(fmt),
-        y_iris, random_state=42
+        sparse.coo_matrix(scale(X_iris)).asformat(fmt), y_iris, random_state=42
     )
-    estimators = [('lr', LogisticRegression()), ('svc', LinearSVC())]
+    estimators = [("lr", LogisticRegression()), ("svc", LinearSVC())]
     rf = RandomForestClassifier(n_estimators=10, random_state=42)
     clf = StackingClassifier(
         estimators=estimators, final_estimator=rf, cv=5, passthrough=True
@@ -255,16 +248,14 @@ def test_stacking_classifier_drop_binary_prob():
     # Select only the 2 first classes
     X_, y_ = scale(X_iris[:100]), y_iris[:100]
 
-    estimators = [
-        ('lr', LogisticRegression()), ('rf', RandomForestClassifier())
-    ]
+    estimators = [("lr", LogisticRegression()), ("rf", RandomForestClassifier())]
     clf = StackingClassifier(estimators=estimators)
     clf.fit(X_, y_)
     X_meta = clf.transform(X_)
     assert X_meta.shape[1] == 2
 
 
-class NoWeightRegressor(BaseEstimator, RegressorMixin):
+class NoWeightRegressor(RegressorMixin, BaseEstimator):
     def fit(self, X, y):
         self.reg = DummyRegressor()
         return self.reg.fit(X, y)
@@ -273,80 +264,118 @@ class NoWeightRegressor(BaseEstimator, RegressorMixin):
         return np.ones(X.shape[0])
 
 
-class NoWeightClassifier(BaseEstimator, ClassifierMixin):
+class NoWeightClassifier(ClassifierMixin, BaseEstimator):
     def fit(self, X, y):
-        self.clf = DummyClassifier(strategy='stratified')
+        self.clf = DummyClassifier(strategy="stratified")
         return self.clf.fit(X, y)
 
 
 @pytest.mark.parametrize(
     "y, params, type_err, msg_err",
-    [(y_iris,
-      {'estimators': None},
-      ValueError, "Invalid 'estimators' attribute,"),
-     (y_iris,
-      {'estimators': []},
-      ValueError, "Invalid 'estimators' attribute,"),
-     (y_iris,
-      {'estimators': [('lr', LogisticRegression()),
-                      ('svm', SVC(max_iter=5e4))],
-       'stack_method': 'predict_proba'},
-      ValueError, 'does not implement the method predict_proba'),
-     (y_iris,
-      {'estimators': [('lr', LogisticRegression()),
-                      ('cor', NoWeightClassifier())]},
-      TypeError, 'does not support sample weight'),
-     (y_iris,
-      {'estimators': [('lr', LogisticRegression()),
-                      ('cor', LinearSVC(max_iter=5e4))],
-       'final_estimator': NoWeightClassifier()},
-      TypeError, 'does not support sample weight')]
+    [
+        (y_iris, {"estimators": None}, ValueError, "Invalid 'estimators' attribute,"),
+        (y_iris, {"estimators": []}, ValueError, "Invalid 'estimators' attribute,"),
+        (
+            y_iris,
+            {
+                "estimators": [
+                    ("lr", LogisticRegression()),
+                    ("svm", SVC(max_iter=5e4)),
+                ],
+                "stack_method": "predict_proba",
+            },
+            ValueError,
+            "does not implement the method predict_proba",
+        ),
+        (
+            y_iris,
+            {
+                "estimators": [
+                    ("lr", LogisticRegression()),
+                    ("cor", NoWeightClassifier()),
+                ]
+            },
+            TypeError,
+            "does not support sample weight",
+        ),
+        (
+            y_iris,
+            {
+                "estimators": [
+                    ("lr", LogisticRegression()),
+                    ("cor", LinearSVC(max_iter=5e4)),
+                ],
+                "final_estimator": NoWeightClassifier(),
+            },
+            TypeError,
+            "does not support sample weight",
+        ),
+    ],
 )
 def test_stacking_classifier_error(y, params, type_err, msg_err):
     with pytest.raises(type_err, match=msg_err):
         clf = StackingClassifier(**params, cv=3)
-        clf.fit(
-            scale(X_iris), y, sample_weight=np.ones(X_iris.shape[0])
-        )
+        clf.fit(scale(X_iris), y, sample_weight=np.ones(X_iris.shape[0]))
 
 
 @pytest.mark.parametrize(
     "y, params, type_err, msg_err",
-    [(y_diabetes,
-      {'estimators': None},
-      ValueError, "Invalid 'estimators' attribute,"),
-     (y_diabetes,
-      {'estimators': []},
-      ValueError, "Invalid 'estimators' attribute,"),
-     (y_diabetes,
-      {'estimators': [('lr', LinearRegression()),
-                      ('cor', NoWeightRegressor())]},
-      TypeError, 'does not support sample weight'),
-     (y_diabetes,
-      {'estimators': [('lr', LinearRegression()),
-                      ('cor', LinearSVR())],
-       'final_estimator': NoWeightRegressor()},
-      TypeError, 'does not support sample weight')]
+    [
+        (
+            y_diabetes,
+            {"estimators": None},
+            ValueError,
+            "Invalid 'estimators' attribute,",
+        ),
+        (y_diabetes, {"estimators": []}, ValueError, "Invalid 'estimators' attribute,"),
+        (
+            y_diabetes,
+            {"estimators": [("lr", LinearRegression()), ("cor", NoWeightRegressor())]},
+            TypeError,
+            "does not support sample weight",
+        ),
+        (
+            y_diabetes,
+            {
+                "estimators": [("lr", LinearRegression()), ("cor", LinearSVR())],
+                "final_estimator": NoWeightRegressor(),
+            },
+            TypeError,
+            "does not support sample weight",
+        ),
+    ],
 )
 def test_stacking_regressor_error(y, params, type_err, msg_err):
     with pytest.raises(type_err, match=msg_err):
         reg = StackingRegressor(**params, cv=3)
-        reg.fit(
-            scale(X_diabetes), y, sample_weight=np.ones(X_diabetes.shape[0])
-        )
+        reg.fit(scale(X_diabetes), y, sample_weight=np.ones(X_diabetes.shape[0]))
 
 
 @pytest.mark.parametrize(
     "estimator, X, y",
-    [(StackingClassifier(
-        estimators=[('lr', LogisticRegression(random_state=0)),
-                    ('svm', LinearSVC(random_state=0))]),
-      X_iris[:100], y_iris[:100]),  # keep only classes 0 and 1
-     (StackingRegressor(
-         estimators=[('lr', LinearRegression()),
-                     ('svm', LinearSVR(random_state=0))]),
-      X_diabetes, y_diabetes)],
-    ids=['StackingClassifier', 'StackingRegressor']
+    [
+        (
+            StackingClassifier(
+                estimators=[
+                    ("lr", LogisticRegression(random_state=0)),
+                    ("svm", LinearSVC(random_state=0)),
+                ]
+            ),
+            X_iris[:100],
+            y_iris[:100],
+        ),  # keep only classes 0 and 1
+        (
+            StackingRegressor(
+                estimators=[
+                    ("lr", LinearRegression()),
+                    ("svm", LinearSVR(random_state=0)),
+                ]
+            ),
+            X_diabetes,
+            y_diabetes,
+        ),
+    ],
+    ids=["StackingClassifier", "StackingRegressor"],
 )
 def test_stacking_randomness(estimator, X, y):
     # checking that fixing the random state of the CV will lead to the same
@@ -357,40 +386,24 @@ def test_stacking_randomness(estimator, X, y):
     )
 
     estimator_drop = clone(estimator)
-    estimator_drop.set_params(lr='drop')
+    estimator_drop.set_params(lr="drop")
     estimator_drop.set_params(
         cv=KFold(shuffle=True, random_state=np.random.RandomState(0))
     )
 
     assert_allclose(
         estimator_full.fit(X, y).transform(X)[:, 1:],
-        estimator_drop.fit(X, y).transform(X)
+        estimator_drop.fit(X, y).transform(X),
     )
 
 
-# These warnings are raised due to _BaseComposition
-@pytest.mark.filterwarnings("ignore:TypeError occurred during set_params")
-@pytest.mark.filterwarnings("ignore:Estimator's parameters changed after")
-@pytest.mark.parametrize(
-    "estimator",
-    [StackingClassifier(
-        estimators=[('lr', LogisticRegression(random_state=0)),
-                    ('tree', DecisionTreeClassifier(random_state=0))]),
-     StackingRegressor(
-         estimators=[('lr', LinearRegression()),
-                     ('tree', DecisionTreeRegressor(random_state=0))])],
-    ids=['StackingClassifier', 'StackingRegressor']
-)
-def test_check_estimators_stacking_estimator(estimator):
-    check_estimator(estimator)
-    check_no_attributes_set_in_init(estimator.__class__.__name__, estimator)
-
-
 def test_stacking_classifier_stratify_default():
     # check that we stratify the classes for the default CV
     clf = StackingClassifier(
-        estimators=[('lr', LogisticRegression(max_iter=1e4)),
-                    ('svm', LinearSVC(max_iter=1e4))]
+        estimators=[
+            ("lr", LogisticRegression(max_iter=1e4)),
+            ("svm", LinearSVC(max_iter=1e4)),
+        ]
     )
     # since iris is not shuffled, a simple k-fold would not contain the
     # 3 classes during training
@@ -399,19 +412,32 @@ def test_stacking_classifier_stratify_default():
 
 @pytest.mark.parametrize(
     "stacker, X, y",
-    [(StackingClassifier(
-        estimators=[('lr', LogisticRegression()),
-                    ('svm', LinearSVC(random_state=42))],
-        final_estimator=LogisticRegression(),
-        cv=KFold(shuffle=True, random_state=42)),
-      *load_breast_cancer(return_X_y=True)),
-     (StackingRegressor(
-         estimators=[('lr', LinearRegression()),
-                     ('svm', LinearSVR(random_state=42))],
-         final_estimator=LinearRegression(),
-         cv=KFold(shuffle=True, random_state=42)),
-      X_diabetes, y_diabetes)],
-    ids=['StackingClassifier', 'StackingRegressor']
+    [
+        (
+            StackingClassifier(
+                estimators=[
+                    ("lr", LogisticRegression()),
+                    ("svm", LinearSVC(random_state=42)),
+                ],
+                final_estimator=LogisticRegression(),
+                cv=KFold(shuffle=True, random_state=42),
+            ),
+            *load_breast_cancer(return_X_y=True),
+        ),
+        (
+            StackingRegressor(
+                estimators=[
+                    ("lr", LinearRegression()),
+                    ("svm", LinearSVR(random_state=42)),
+                ],
+                final_estimator=LinearRegression(),
+                cv=KFold(shuffle=True, random_state=42),
+            ),
+            X_diabetes,
+            y_diabetes,
+        ),
+    ],
+    ids=["StackingClassifier", "StackingRegressor"],
 )
 def test_stacking_with_sample_weight(stacker, X, y):
     # check that sample weights has an influence on the fitting
@@ -445,12 +471,8 @@ def test_stacking_with_sample_weight(stacker, X, y):
 def test_stacking_classifier_sample_weight_fit_param():
     # check sample_weight is passed to all invocations of fit
     stacker = StackingClassifier(
-        estimators=[
-            ('lr', CheckingClassifier(expected_fit_params=['sample_weight']))
-        ],
-        final_estimator=CheckingClassifier(
-            expected_fit_params=['sample_weight']
-        )
+        estimators=[("lr", CheckingClassifier(expected_fit_params=["sample_weight"]))],
+        final_estimator=CheckingClassifier(expected_fit_params=["sample_weight"]),
     )
     stacker.fit(X_iris, y_iris, sample_weight=np.ones(X_iris.shape[0]))
 
@@ -458,17 +480,30 @@ def test_stacking_classifier_sample_weight_fit_param():
 @pytest.mark.filterwarnings("ignore::sklearn.exceptions.ConvergenceWarning")
 @pytest.mark.parametrize(
     "stacker, X, y",
-    [(StackingClassifier(
-        estimators=[('lr', LogisticRegression()),
-                    ('svm', LinearSVC(random_state=42))],
-        final_estimator=LogisticRegression()),
-      *load_breast_cancer(return_X_y=True)),
-     (StackingRegressor(
-         estimators=[('lr', LinearRegression()),
-                     ('svm', LinearSVR(random_state=42))],
-         final_estimator=LinearRegression()),
-      X_diabetes, y_diabetes)],
-    ids=['StackingClassifier', 'StackingRegressor']
+    [
+        (
+            StackingClassifier(
+                estimators=[
+                    ("lr", LogisticRegression()),
+                    ("svm", LinearSVC(random_state=42)),
+                ],
+                final_estimator=LogisticRegression(),
+            ),
+            *load_breast_cancer(return_X_y=True),
+        ),
+        (
+            StackingRegressor(
+                estimators=[
+                    ("lr", LinearRegression()),
+                    ("svm", LinearSVR(random_state=42)),
+                ],
+                final_estimator=LinearRegression(),
+            ),
+            X_diabetes,
+            y_diabetes,
+        ),
+    ],
+    ids=["StackingClassifier", "StackingRegressor"],
 )
 def test_stacking_cv_influence(stacker, X, y):
     # check that the stacking affects the fit of the final estimator but not
@@ -485,32 +520,36 @@ def test_stacking_cv_influence(stacker, X, y):
     stacker_cv_5.fit(X, y)
 
     # the base estimators should be identical
-    for est_cv_3, est_cv_5 in zip(stacker_cv_3.estimators_,
-                                  stacker_cv_5.estimators_):
+    for est_cv_3, est_cv_5 in zip(stacker_cv_3.estimators_, stacker_cv_5.estimators_):
         assert_allclose(est_cv_3.coef_, est_cv_5.coef_)
 
     # the final estimator should be different
-    with pytest.raises(AssertionError, match='Not equal'):
-        assert_allclose(stacker_cv_3.final_estimator_.coef_,
-                        stacker_cv_5.final_estimator_.coef_)
+    with pytest.raises(AssertionError, match="Not equal"):
+        assert_allclose(
+            stacker_cv_3.final_estimator_.coef_, stacker_cv_5.final_estimator_.coef_
+        )
 
 
-@pytest.mark.parametrize("make_dataset, Stacking, Estimator", [
-    (make_classification, StackingClassifier, LogisticRegression),
-    (make_regression, StackingRegressor, LinearRegression)
-])
+@pytest.mark.parametrize(
+    "make_dataset, Stacking, Estimator",
+    [
+        (make_classification, StackingClassifier, LogisticRegression),
+        (make_regression, StackingRegressor, LinearRegression),
+    ],
+)
 def test_stacking_without_n_features_in(make_dataset, Stacking, Estimator):
     # Stacking supports estimators without `n_features_in_`. Regression test
     # for #17353
 
     class MyEstimator(Estimator):
         """Estimator without n_features_in_"""
+
         def fit(self, X, y):
             super().fit(X, y)
             del self.n_features_in_
 
     X, y = make_dataset(random_state=0, n_samples=100)
-    stacker = Stacking(estimators=[('lr', MyEstimator())])
+    stacker = Stacking(estimators=[("lr", MyEstimator())])
 
     msg = f"{Stacking.__name__} object has no attribute n_features_in_"
     with pytest.raises(AttributeError, match=msg):
