@@ -11,8 +11,6 @@ from scipy.sparse import lil_matrix
 
 from sklearn.utils._testing import assert_array_equal, assert_array_less
 from sklearn.utils._testing import assert_array_almost_equal
-from sklearn.utils._testing import assert_raises, assert_raises_regexp
-from sklearn.utils._testing import ignore_warnings
 
 from sklearn.base import BaseEstimator
 from sklearn.base import clone
@@ -35,7 +33,7 @@ rng = np.random.RandomState(0)
 
 # Toy sample
 X = [[-2, -1], [-1, -1], [-1, -2], [1, 1], [1, 2], [2, 1]]
-y_class = ["foo", "foo", "foo", 1, 1, 1]    # test string class labels
+y_class = ["foo", "foo", "foo", 1, 1, 1]  # test string class labels
 y_regr = [-1, -1, -1, 1, 1, 1]
 T = [[-1, -1], [2, 2], [3, 2]]
 y_t_class = ["foo", 1, 1]
@@ -46,20 +44,20 @@ iris = datasets.load_iris()
 perm = rng.permutation(iris.target.size)
 iris.data, iris.target = shuffle(iris.data, iris.target, random_state=rng)
 
-# Load the boston dataset and randomly permute it
-boston = datasets.load_boston()
-boston.data, boston.target = shuffle(boston.data, boston.target,
-                                     random_state=rng)
+# Load the diabetes dataset and randomly permute it
+diabetes = datasets.load_diabetes()
+diabetes.data, diabetes.target = shuffle(
+    diabetes.data, diabetes.target, random_state=rng
+)
 
 
 def test_samme_proba():
     # Test the `_samme_proba` helper function.
 
     # Define some example (bad) `predict_proba` output.
-    probs = np.array([[1, 1e-6, 0],
-                      [0.19, 0.6, 0.2],
-                      [-999, 0.51, 0.5],
-                      [1e-6, 1, 1e-9]])
+    probs = np.array(
+        [[1, 1e-6, 0], [0.19, 0.6, 0.2], [-999, 0.51, 0.5], [1e-6, 1, 1e-9]]
+    )
     probs /= np.abs(probs.sum(axis=1))[:, np.newaxis]
 
     # _samme_proba calls estimator.predict_proba.
@@ -68,6 +66,7 @@ def test_samme_proba():
         def predict_proba(self, X):
             assert_array_equal(X.shape, probs.shape)
             return probs
+
     mock = MockEstimator()
 
     samme_proba = _samme_proba(mock, 3, np.ones_like(probs))
@@ -113,7 +112,7 @@ def test_iris():
     classes = np.unique(iris.target)
     clf_samme = prob_samme = None
 
-    for alg in ['SAMME', 'SAMME.R']:
+    for alg in ["SAMME", "SAMME.R"]:
         clf = AdaBoostClassifier(algorithm=alg)
         clf.fit(iris.data, iris.target)
 
@@ -126,36 +125,34 @@ def test_iris():
         assert clf.decision_function(iris.data).shape[1] == len(classes)
 
         score = clf.score(iris.data, iris.target)
-        assert score > 0.9, "Failed with algorithm %s and score = %f" % \
-            (alg, score)
+        assert score > 0.9, "Failed with algorithm %s and score = %f" % (alg, score)
 
         # Check we used multiple estimators
         assert len(clf.estimators_) > 1
         # Check for distinct random states (see issue #7408)
-        assert (len(set(est.random_state for est in clf.estimators_)) ==
-                     len(clf.estimators_))
+        assert len(set(est.random_state for est in clf.estimators_)) == len(
+            clf.estimators_
+        )
 
     # Somewhat hacky regression test: prior to
     # ae7adc880d624615a34bafdb1d75ef67051b8200,
     # predict_proba returned SAMME.R values for SAMME.
     clf_samme.algorithm = "SAMME.R"
-    assert_array_less(0,
-                      np.abs(clf_samme.predict_proba(iris.data) - prob_samme))
+    assert_array_less(0, np.abs(clf_samme.predict_proba(iris.data) - prob_samme))
 
 
-@pytest.mark.parametrize('loss', ['linear', 'square', 'exponential'])
-def test_boston(loss):
-    # Check consistency on dataset boston house prices.
+@pytest.mark.parametrize("loss", ["linear", "square", "exponential"])
+def test_diabetes(loss):
+    # Check consistency on dataset diabetes.
     reg = AdaBoostRegressor(loss=loss, random_state=0)
-    reg.fit(boston.data, boston.target)
-    score = reg.score(boston.data, boston.target)
-    assert score > 0.85
+    reg.fit(diabetes.data, diabetes.target)
+    score = reg.score(diabetes.data, diabetes.target)
+    assert score > 0.6
 
     # Check we used multiple estimators
     assert len(reg.estimators_) > 1
     # Check for distinct random states (see issue #7408)
-    assert (len(set(est.random_state for est in reg.estimators_)) ==
-                 len(reg.estimators_))
+    assert len(set(est.random_state for est in reg.estimators_)) == len(reg.estimators_)
 
 
 @pytest.mark.parametrize("algorithm", ["SAMME", "SAMME.R"])
@@ -163,7 +160,7 @@ def test_staged_predict(algorithm):
     # Check staged predictions.
     rng = np.random.RandomState(0)
     iris_weights = rng.randint(10, size=iris.target.shape)
-    boston_weights = rng.randint(10, size=boston.target.shape)
+    diabetes_weights = rng.randint(10, size=diabetes.target.shape)
 
     clf = AdaBoostClassifier(algorithm=algorithm, n_estimators=10)
     clf.fit(iris.data, iris.target, sample_weight=iris_weights)
@@ -174,8 +171,8 @@ def test_staged_predict(algorithm):
     staged_probas = [p for p in clf.staged_predict_proba(iris.data)]
     score = clf.score(iris.data, iris.target, sample_weight=iris_weights)
     staged_scores = [
-        s for s in clf.staged_score(
-            iris.data, iris.target, sample_weight=iris_weights)]
+        s for s in clf.staged_score(iris.data, iris.target, sample_weight=iris_weights)
+    ]
 
     assert len(staged_predictions) == 10
     assert_array_almost_equal(predictions, staged_predictions[-1])
@@ -186,14 +183,17 @@ def test_staged_predict(algorithm):
 
     # AdaBoost regression
     clf = AdaBoostRegressor(n_estimators=10, random_state=0)
-    clf.fit(boston.data, boston.target, sample_weight=boston_weights)
+    clf.fit(diabetes.data, diabetes.target, sample_weight=diabetes_weights)
 
-    predictions = clf.predict(boston.data)
-    staged_predictions = [p for p in clf.staged_predict(boston.data)]
-    score = clf.score(boston.data, boston.target, sample_weight=boston_weights)
+    predictions = clf.predict(diabetes.data)
+    staged_predictions = [p for p in clf.staged_predict(diabetes.data)]
+    score = clf.score(diabetes.data, diabetes.target, sample_weight=diabetes_weights)
     staged_scores = [
-        s for s in clf.staged_score(
-            boston.data, boston.target, sample_weight=boston_weights)]
+        s
+        for s in clf.staged_score(
+            diabetes.data, diabetes.target, sample_weight=diabetes_weights
+        )
+    ]
 
     assert len(staged_predictions) == 10
     assert_array_almost_equal(predictions, staged_predictions[-1])
@@ -205,19 +205,19 @@ def test_gridsearch():
     # Check that base trees can be grid-searched.
     # AdaBoost classification
     boost = AdaBoostClassifier(base_estimator=DecisionTreeClassifier())
-    parameters = {'n_estimators': (1, 2),
-                  'base_estimator__max_depth': (1, 2),
-                  'algorithm': ('SAMME', 'SAMME.R')}
+    parameters = {
+        "n_estimators": (1, 2),
+        "base_estimator__max_depth": (1, 2),
+        "algorithm": ("SAMME", "SAMME.R"),
+    }
     clf = GridSearchCV(boost, parameters)
     clf.fit(iris.data, iris.target)
 
     # AdaBoost regression
-    boost = AdaBoostRegressor(base_estimator=DecisionTreeRegressor(),
-                              random_state=0)
-    parameters = {'n_estimators': (1, 2),
-                  'base_estimator__max_depth': (1, 2)}
+    boost = AdaBoostRegressor(base_estimator=DecisionTreeRegressor(), random_state=0)
+    parameters = {"n_estimators": (1, 2), "base_estimator__max_depth": (1, 2)}
     clf = GridSearchCV(boost, parameters)
-    clf.fit(boston.data, boston.target)
+    clf.fit(diabetes.data, diabetes.target)
 
 
 def test_pickle():
@@ -225,7 +225,7 @@ def test_pickle():
     import pickle
 
     # Adaboost classifier
-    for alg in ['SAMME', 'SAMME.R']:
+    for alg in ["SAMME", "SAMME.R"]:
         obj = AdaBoostClassifier(algorithm=alg)
         obj.fit(iris.data, iris.target)
         score = obj.score(iris.data, iris.target)
@@ -238,27 +238,29 @@ def test_pickle():
 
     # Adaboost regressor
     obj = AdaBoostRegressor(random_state=0)
-    obj.fit(boston.data, boston.target)
-    score = obj.score(boston.data, boston.target)
+    obj.fit(diabetes.data, diabetes.target)
+    score = obj.score(diabetes.data, diabetes.target)
     s = pickle.dumps(obj)
 
     obj2 = pickle.loads(s)
     assert type(obj2) == obj.__class__
-    score2 = obj2.score(boston.data, boston.target)
+    score2 = obj2.score(diabetes.data, diabetes.target)
     assert score == score2
 
 
 def test_importances():
     # Check variable importances.
-    X, y = datasets.make_classification(n_samples=2000,
-                                        n_features=10,
-                                        n_informative=3,
-                                        n_redundant=0,
-                                        n_repeated=0,
-                                        shuffle=False,
-                                        random_state=1)
+    X, y = datasets.make_classification(
+        n_samples=2000,
+        n_features=10,
+        n_informative=3,
+        n_redundant=0,
+        n_repeated=0,
+        shuffle=False,
+        random_state=1,
+    )
 
-    for alg in ['SAMME', 'SAMME.R']:
+    for alg in ["SAMME", "SAMME.R"]:
         clf = AdaBoostClassifier(algorithm=alg)
 
         clf.fit(X, y)
@@ -270,17 +272,15 @@ def test_importances():
 
 def test_error():
     # Test that it gives proper exception on deficient input.
-    assert_raises(ValueError,
-                  AdaBoostClassifier(learning_rate=-1).fit,
-                  X, y_class)
 
-    assert_raises(ValueError,
-                  AdaBoostClassifier(algorithm="foo").fit,
-                  X, y_class)
+    with pytest.raises(ValueError):
+        AdaBoostClassifier(learning_rate=-1).fit(X, y_class)
 
-    assert_raises(ValueError,
-                  AdaBoostClassifier().fit,
-                  X, y_class, sample_weight=np.asarray([-1]))
+    with pytest.raises(ValueError):
+        AdaBoostClassifier(algorithm="foo").fit(X, y_class)
+
+    with pytest.raises(ValueError):
+        AdaBoostClassifier().fit(X, y_class, sample_weight=np.asarray([-1]))
 
 
 def test_base_estimator():
@@ -307,8 +307,15 @@ def test_base_estimator():
     X_fail = [[1, 1], [1, 1], [1, 1], [1, 1]]
     y_fail = ["foo", "bar", 1, 2]
     clf = AdaBoostClassifier(SVC(), algorithm="SAMME")
-    assert_raises_regexp(ValueError, "worse than random",
-                         clf.fit, X_fail, y_fail)
+    with pytest.raises(ValueError, match="worse than random"):
+        clf.fit(X_fail, y_fail)
+
+
+def test_sample_weights_infinite():
+    msg = "Sample weights have reached infinite values"
+    clf = AdaBoostClassifier(n_estimators=30, learning_rate=5.0, algorithm="SAMME")
+    with pytest.warns(UserWarning, match=msg):
+        clf.fit(iris.data, iris.target)
 
 
 def test_sparse_classification():
@@ -323,16 +330,15 @@ def test_sparse_classification():
             self.data_type_ = type(X)
             return self
 
-    X, y = datasets.make_multilabel_classification(n_classes=1, n_samples=15,
-                                                   n_features=5,
-                                                   random_state=42)
+    X, y = datasets.make_multilabel_classification(
+        n_classes=1, n_samples=15, n_features=5, random_state=42
+    )
     # Flatten y to a 1d array
     y = np.ravel(y)
 
     X_train, X_test, y_train, y_test = train_test_split(X, y, random_state=0)
 
-    for sparse_format in [csc_matrix, csr_matrix, lil_matrix, coo_matrix,
-                          dok_matrix]:
+    for sparse_format in [csc_matrix, csr_matrix, lil_matrix, coo_matrix, dok_matrix]:
         X_train_sparse = sparse_format(X_train)
         X_test_sparse = sparse_format(X_test)
 
@@ -340,14 +346,14 @@ def test_sparse_classification():
         sparse_classifier = AdaBoostClassifier(
             base_estimator=CustomSVC(probability=True),
             random_state=1,
-            algorithm="SAMME"
+            algorithm="SAMME",
         ).fit(X_train_sparse, y_train)
 
         # Trained on dense format
         dense_classifier = AdaBoostClassifier(
             base_estimator=CustomSVC(probability=True),
             random_state=1,
-            algorithm="SAMME"
+            algorithm="SAMME",
         ).fit(X_train, y_train)
 
         # predict
@@ -376,8 +382,7 @@ def test_sparse_classification():
         assert_array_almost_equal(sparse_results, dense_results)
 
         # staged_decision_function
-        sparse_results = sparse_classifier.staged_decision_function(
-            X_test_sparse)
+        sparse_results = sparse_classifier.staged_decision_function(X_test_sparse)
         dense_results = dense_classifier.staged_decision_function(X_test)
         for sprase_res, dense_res in zip(sparse_results, dense_results):
             assert_array_almost_equal(sprase_res, dense_res)
@@ -395,8 +400,7 @@ def test_sparse_classification():
             assert_array_almost_equal(sprase_res, dense_res)
 
         # staged_score
-        sparse_results = sparse_classifier.staged_score(X_test_sparse,
-                                                        y_test)
+        sparse_results = sparse_classifier.staged_score(X_test_sparse, y_test)
         dense_results = dense_classifier.staged_score(X_test, y_test)
         for sprase_res, dense_res in zip(sparse_results, dense_results):
             assert_array_equal(sprase_res, dense_res)
@@ -404,8 +408,7 @@ def test_sparse_classification():
         # Verify sparsity of data is maintained during training
         types = [i.data_type_ for i in sparse_classifier.estimators_]
 
-        assert all([(t == csc_matrix or t == csr_matrix)
-                   for t in types])
+        assert all([(t == csc_matrix or t == csr_matrix) for t in types])
 
 
 def test_sparse_regression():
@@ -420,26 +423,24 @@ def test_sparse_regression():
             self.data_type_ = type(X)
             return self
 
-    X, y = datasets.make_regression(n_samples=15, n_features=50, n_targets=1,
-                                    random_state=42)
+    X, y = datasets.make_regression(
+        n_samples=15, n_features=50, n_targets=1, random_state=42
+    )
 
     X_train, X_test, y_train, y_test = train_test_split(X, y, random_state=0)
 
-    for sparse_format in [csc_matrix, csr_matrix, lil_matrix, coo_matrix,
-                          dok_matrix]:
+    for sparse_format in [csc_matrix, csr_matrix, lil_matrix, coo_matrix, dok_matrix]:
         X_train_sparse = sparse_format(X_train)
         X_test_sparse = sparse_format(X_test)
 
         # Trained on sparse format
         sparse_classifier = AdaBoostRegressor(
-            base_estimator=CustomSVR(),
-            random_state=1
+            base_estimator=CustomSVR(), random_state=1
         ).fit(X_train_sparse, y_train)
 
         # Trained on dense format
         dense_classifier = dense_results = AdaBoostRegressor(
-            base_estimator=CustomSVR(),
-            random_state=1
+            base_estimator=CustomSVR(), random_state=1
         ).fit(X_train, y_train)
 
         # predict
@@ -455,8 +456,7 @@ def test_sparse_regression():
 
         types = [i.data_type_ for i in sparse_classifier.estimators_]
 
-        assert all([(t == csc_matrix or t == csr_matrix)
-                   for t in types])
+        assert all([(t == csc_matrix or t == csr_matrix) for t in types])
 
 
 def test_sample_weight_adaboost_regressor():
@@ -465,8 +465,8 @@ def test_sample_weight_adaboost_regressor():
     The random weighted sampling is done internally in the _boost method in
     AdaBoostRegressor.
     """
-    class DummyEstimator(BaseEstimator):
 
+    class DummyEstimator(BaseEstimator):
         def fit(self, X, y):
             pass
 
@@ -489,7 +489,7 @@ def test_multidimensional_X():
     yc = rng.choice([0, 1], 50)
     yr = rng.randn(50)
 
-    boost = AdaBoostClassifier(DummyClassifier(strategy='most_frequent'))
+    boost = AdaBoostClassifier(DummyClassifier(strategy="most_frequent"))
     boost.fit(X, yc)
     boost.predict(X)
     boost.predict_proba(X)
@@ -499,17 +499,14 @@ def test_multidimensional_X():
     boost.predict(X)
 
 
-# TODO: Remove in 0.24 when DummyClassifier's `strategy` default changes
-@ignore_warnings
-@pytest.mark.parametrize("algorithm", ['SAMME', 'SAMME.R'])
+@pytest.mark.parametrize("algorithm", ["SAMME", "SAMME.R"])
 def test_adaboostclassifier_without_sample_weight(algorithm):
     X, y = iris.data, iris.target
     base_estimator = NoSampleWeightWrapper(DummyClassifier())
-    clf = AdaBoostClassifier(
-        base_estimator=base_estimator, algorithm=algorithm
+    clf = AdaBoostClassifier(base_estimator=base_estimator, algorithm=algorithm)
+    err_msg = "{} doesn't support sample_weight".format(
+        base_estimator.__class__.__name__
     )
-    err_msg = ("{} doesn't support sample_weight"
-               .format(base_estimator.__class__.__name__))
     with pytest.raises(ValueError, match=err_msg):
         clf.fit(X, y)
 
@@ -519,7 +516,7 @@ def test_adaboostregressor_sample_weight():
     # for a weak learner
     rng = np.random.RandomState(42)
     X = np.linspace(0, 100, num=1000)
-    y = (.8 * X + 0.2) + (rng.rand(X.shape[0]) * 0.0001)
+    y = (0.8 * X + 0.2) + (rng.rand(X.shape[0]) * 0.0001)
     X = X.reshape(-1, 1)
 
     # add an arbitrary outlier
@@ -551,6 +548,7 @@ def test_adaboostregressor_sample_weight():
     assert score_with_outlier < score_with_weight
     assert score_no_outlier == pytest.approx(score_with_weight)
 
+
 @pytest.mark.parametrize("algorithm", ["SAMME", "SAMME.R"])
 def test_adaboost_consistent_predict(algorithm):
     # check that predict_proba and predict give consistent results
@@ -563,15 +561,16 @@ def test_adaboost_consistent_predict(algorithm):
     model.fit(X_train, y_train)
 
     assert_array_equal(
-        np.argmax(model.predict_proba(X_test), axis=1),
-        model.predict(X_test)
+        np.argmax(model.predict_proba(X_test), axis=1), model.predict(X_test)
     )
 
 
 @pytest.mark.parametrize(
-    'model, X, y',
-    [(AdaBoostClassifier(), iris.data, iris.target),
-     (AdaBoostRegressor(), boston.data, boston.target)]
+    "model, X, y",
+    [
+        (AdaBoostClassifier(), iris.data, iris.target),
+        (AdaBoostRegressor(), diabetes.data, diabetes.target),
+    ],
 )
 def test_adaboost_negative_weight_error(model, X, y):
     sample_weight = np.ones_like(y)
