@@ -11,12 +11,11 @@ import math
 
 from .base import BaseEstimator, TransformerMixin, RegressorMixin
 from .utils import check_array, check_consistent_length
-from .utils.validation import _check_sample_weight, _deprecate_positional_args
+from .utils.validation import _check_sample_weight
 from ._isotonic import _inplace_contiguous_isotonic_regression, _make_unique
 
 
-__all__ = ['check_increasing', 'isotonic_regression',
-           'IsotonicRegression']
+__all__ = ["check_increasing", "isotonic_regression", "IsotonicRegression"]
 
 
 def check_increasing(x, y):
@@ -58,7 +57,7 @@ def check_increasing(x, y):
 
     # Run Fisher transform to get the rho CI, but handle rho=+/-1
     if rho not in [-1.0, 1.0] and len(x) > 3:
-        F = 0.5 * math.log((1. + rho) / (1. - rho))
+        F = 0.5 * math.log((1.0 + rho) / (1.0 - rho))
         F_se = 1 / math.sqrt(len(x) - 3)
 
         # Use a 95% CI, i.e., +/-1.96 S.E.
@@ -68,17 +67,19 @@ def check_increasing(x, y):
 
         # Warn if the CI spans zero.
         if np.sign(rho_0) != np.sign(rho_1):
-            warnings.warn("Confidence interval of the Spearman "
-                          "correlation coefficient spans zero. "
-                          "Determination of ``increasing`` may be "
-                          "suspect.")
+            warnings.warn(
+                "Confidence interval of the Spearman "
+                "correlation coefficient spans zero. "
+                "Determination of ``increasing`` may be "
+                "suspect."
+            )
 
     return increasing_bool
 
 
-@_deprecate_positional_args
-def isotonic_regression(y, *, sample_weight=None, y_min=None, y_max=None,
-                        increasing=True):
+def isotonic_regression(
+    y, *, sample_weight=None, y_min=None, y_max=None, increasing=True
+):
     """Solve the isotonic regression model.
 
     Read more in the :ref:`User Guide <isotonic>`.
@@ -100,7 +101,7 @@ def isotonic_regression(y, *, sample_weight=None, y_min=None, y_max=None,
         Upper bound on the highest predicted value (the maximum may still be
         lower). If not set, defaults to +inf.
 
-    increasing : boolean, optional, default: True
+    increasing : bool, default=True
         Whether to compute ``y_`` is increasing (if set to True) or decreasing
         (if set to False)
 
@@ -117,7 +118,7 @@ def isotonic_regression(y, *, sample_weight=None, y_min=None, y_max=None,
     order = np.s_[:] if increasing else np.s_[::-1]
     y = check_array(y, ensure_2d=False, dtype=[np.float64, np.float32])
     y = np.array(y[order], dtype=y.dtype)
-    sample_weight = _check_sample_weight(sample_weight, y, dtype=y.dtype)
+    sample_weight = _check_sample_weight(sample_weight, y, dtype=y.dtype, copy=True)
     sample_weight = np.ascontiguousarray(sample_weight[order])
 
     _inplace_contiguous_isotonic_regression(y, sample_weight)
@@ -153,13 +154,14 @@ class IsotonicRegression(RegressorMixin, TransformerMixin, BaseEstimator):
         or decrease with `X`. 'auto' will decide based on the Spearman
         correlation estimate's sign.
 
-    out_of_bounds : str, default="nan"
-        The ``out_of_bounds`` parameter handles how `X` values outside of the
-        training domain are handled.  When set to "nan", predictions
-        will be NaN.  When set to "clip", predictions will be
-        set to the value corresponding to the nearest train interval endpoint.
-        When set to "raise" a `ValueError` is raised.
+    out_of_bounds : {'nan', 'clip', 'raise'}, default='nan'
+        Handles how `X` values outside of the training domain are handled
+        during prediction.
 
+        - 'nan', predictions will be NaN.
+        - 'clip', predictions will be set to the value corresponding to
+          the nearest train interval endpoint.
+        - 'raise', a `ValueError` is raised.
 
     Attributes
     ----------
@@ -169,15 +171,35 @@ class IsotonicRegression(RegressorMixin, TransformerMixin, BaseEstimator):
     X_max_ : float
         Maximum value of input array `X_` for right bound.
 
+    X_thresholds_ : ndarray of shape (n_thresholds,)
+        Unique ascending `X` values used to interpolate
+        the y = f(X) monotonic function.
+
+        .. versionadded:: 0.24
+
+    y_thresholds_ : ndarray of shape (n_thresholds,)
+        De-duplicated `y` values suitable to interpolate the y = f(X)
+        monotonic function.
+
+        .. versionadded:: 0.24
+
     f_ : function
         The stepwise interpolating function that covers the input domain ``X``.
 
     increasing_ : bool
         Inferred value for ``increasing``.
 
+    See Also
+    --------
+    sklearn.linear_model.LinearRegression : Ordinary least squares Linear
+        Regression.
+    sklearn.ensemble.HistGradientBoostingRegressor : Gradient boosting that
+        is a non-parametric model accepting monotonicity constraints.
+    isotonic_regression : Function to solve the isotonic regression model.
+
     Notes
     -----
-    Ties are broken using the secondary method from Leeuw, 1977.
+    Ties are broken using the secondary method from de Leeuw, 1977.
 
     References
     ----------
@@ -188,56 +210,62 @@ class IsotonicRegression(RegressorMixin, TransformerMixin, BaseEstimator):
 
     Isotone Optimization in R : Pool-Adjacent-Violators
     Algorithm (PAVA) and Active Set Methods
-    Leeuw, Hornik, Mair
+    de Leeuw, Hornik, Mair
     Journal of Statistical Software 2009
 
     Correctness of Kruskal's algorithms for monotone regression with ties
-    Leeuw, Psychometrica, 1977
+    de Leeuw, Psychometrica, 1977
 
     Examples
     --------
     >>> from sklearn.datasets import make_regression
     >>> from sklearn.isotonic import IsotonicRegression
     >>> X, y = make_regression(n_samples=10, n_features=1, random_state=41)
-    >>> iso_reg = IsotonicRegression().fit(X.flatten(), y)
+    >>> iso_reg = IsotonicRegression().fit(X, y)
     >>> iso_reg.predict([.1, .2])
     array([1.8628..., 3.7256...])
     """
-    @_deprecate_positional_args
-    def __init__(self, *, y_min=None, y_max=None, increasing=True,
-                 out_of_bounds='nan'):
+
+    def __init__(self, *, y_min=None, y_max=None, increasing=True, out_of_bounds="nan"):
         self.y_min = y_min
         self.y_max = y_max
         self.increasing = increasing
         self.out_of_bounds = out_of_bounds
 
-    def _check_fit_data(self, X, y, sample_weight=None):
-        if len(X.shape) != 1:
-            raise ValueError("X should be a 1d array")
+    def _check_input_data_shape(self, X):
+        if not (X.ndim == 1 or (X.ndim == 2 and X.shape[1] == 1)):
+            msg = (
+                "Isotonic regression input X should be a 1d array or "
+                "2d array with 1 feature"
+            )
+            raise ValueError(msg)
 
     def _build_f(self, X, y):
         """Build the f_ interp1d function."""
 
         # Handle the out_of_bounds argument by setting bounds_error
         if self.out_of_bounds not in ["raise", "nan", "clip"]:
-            raise ValueError("The argument ``out_of_bounds`` must be in "
-                             "'nan', 'clip', 'raise'; got {0}"
-                             .format(self.out_of_bounds))
+            raise ValueError(
+                "The argument ``out_of_bounds`` must be in "
+                "'nan', 'clip', 'raise'; got {0}".format(self.out_of_bounds)
+            )
 
         bounds_error = self.out_of_bounds == "raise"
         if len(y) == 1:
             # single y, constant prediction
             self.f_ = lambda x: y.repeat(x.shape)
         else:
-            self.f_ = interpolate.interp1d(X, y, kind='linear',
-                                           bounds_error=bounds_error)
+            self.f_ = interpolate.interp1d(
+                X, y, kind="linear", bounds_error=bounds_error
+            )
 
     def _build_y(self, X, y, sample_weight, trim_duplicates=True):
         """Build the y_ IsotonicRegression."""
-        self._check_fit_data(X, y, sample_weight)
+        self._check_input_data_shape(X)
+        X = X.reshape(-1)  # use 1d view
 
         # Determine increasing if auto-determination requested
-        if self.increasing == 'auto':
+        if self.increasing == "auto":
             self.increasing_ = check_increasing(X, y)
         else:
             self.increasing_ = self.increasing
@@ -250,13 +278,16 @@ class IsotonicRegression(RegressorMixin, TransformerMixin, BaseEstimator):
 
         order = np.lexsort((y, X))
         X, y, sample_weight = [array[order] for array in [X, y, sample_weight]]
-        unique_X, unique_y, unique_sample_weight = _make_unique(
-            X, y, sample_weight)
+        unique_X, unique_y, unique_sample_weight = _make_unique(X, y, sample_weight)
 
         X = unique_X
-        y = isotonic_regression(unique_y, sample_weight=unique_sample_weight,
-                                y_min=self.y_min, y_max=self.y_max,
-                                increasing=self.increasing_)
+        y = isotonic_regression(
+            unique_y,
+            sample_weight=unique_sample_weight,
+            y_min=self.y_min,
+            y_max=self.y_max,
+            increasing=self.increasing_,
+        )
 
         # Handle the left and right bounds on X
         self.X_min_, self.X_max_ = np.min(X), np.max(X)
@@ -267,8 +298,7 @@ class IsotonicRegression(RegressorMixin, TransformerMixin, BaseEstimator):
             # Aside from the 1st and last point, remove points whose y values
             # are equal to both the point before and the point after it.
             keep_data[1:-1] = np.logical_or(
-                np.not_equal(y[1:-1], y[:-2]),
-                np.not_equal(y[1:-1], y[2:])
+                np.not_equal(y[1:-1], y[:-2]), np.not_equal(y[1:-1], y[2:])
             )
             return X[keep_data], y[keep_data]
         else:
@@ -283,9 +313,12 @@ class IsotonicRegression(RegressorMixin, TransformerMixin, BaseEstimator):
 
         Parameters
         ----------
-        X : array-like of shape (n_samples,)
+        X : array-like of shape (n_samples,) or (n_samples, 1)
             Training data.
 
+            .. versionchanged:: 0.24
+               Also accepts 2d array with 1 feature.
+
         y : array-like of shape (n_samples,)
             Training target.
 
@@ -316,41 +349,45 @@ class IsotonicRegression(RegressorMixin, TransformerMixin, BaseEstimator):
         # on the model to make it possible to support model persistence via
         # the pickle module as the object built by scipy.interp1d is not
         # picklable directly.
-        self._necessary_X_, self._necessary_y_ = X, y
+        self.X_thresholds_, self.y_thresholds_ = X, y
 
         # Build the interpolation function
         self._build_f(X, y)
         return self
 
     def transform(self, T):
-        """Transform new data by linear interpolation
+        """Transform new data by linear interpolation.
 
         Parameters
         ----------
-        T : array-like of shape (n_samples,)
+        T : array-like of shape (n_samples,) or (n_samples, 1)
             Data to transform.
 
+            .. versionchanged:: 0.24
+               Also accepts 2d array with 1 feature.
+
         Returns
         -------
         y_pred : ndarray of shape (n_samples,)
-            The transformed data
+            The transformed data.
         """
 
-        if hasattr(self, '_necessary_X_'):
-            dtype = self._necessary_X_.dtype
+        if hasattr(self, "X_thresholds_"):
+            dtype = self.X_thresholds_.dtype
         else:
             dtype = np.float64
 
         T = check_array(T, dtype=dtype, ensure_2d=False)
 
-        if len(T.shape) != 1:
-            raise ValueError("Isotonic regression input should be a 1d array")
+        self._check_input_data_shape(T)
+        T = T.reshape(-1)  # use 1d view
 
         # Handle the out_of_bounds argument by clipping if needed
         if self.out_of_bounds not in ["raise", "nan", "clip"]:
-            raise ValueError("The argument ``out_of_bounds`` must be in "
-                             "'nan', 'clip', 'raise'; got {0}"
-                             .format(self.out_of_bounds))
+            raise ValueError(
+                "The argument ``out_of_bounds`` must be in "
+                "'nan', 'clip', 'raise'; got {0}".format(self.out_of_bounds)
+            )
 
         if self.out_of_bounds == "clip":
             T = np.clip(T, self.X_min_, self.X_max_)
@@ -367,7 +404,7 @@ class IsotonicRegression(RegressorMixin, TransformerMixin, BaseEstimator):
 
         Parameters
         ----------
-        T : array-like of shape (n_samples,)
+        T : array-like of shape (n_samples,) or (n_samples, 1)
             Data to transform.
 
         Returns
@@ -378,10 +415,10 @@ class IsotonicRegression(RegressorMixin, TransformerMixin, BaseEstimator):
         return self.transform(T)
 
     def __getstate__(self):
-        """Pickle-protocol - return state of the estimator. """
+        """Pickle-protocol - return state of the estimator."""
         state = super().__getstate__()
         # remove interpolation method
-        state.pop('f_', None)
+        state.pop("f_", None)
         return state
 
     def __setstate__(self, state):
@@ -390,8 +427,8 @@ class IsotonicRegression(RegressorMixin, TransformerMixin, BaseEstimator):
         We need to rebuild the interpolation function.
         """
         super().__setstate__(state)
-        if hasattr(self, '_necessary_X_') and hasattr(self, '_necessary_y_'):
-            self._build_f(self._necessary_X_, self._necessary_y_)
+        if hasattr(self, "X_thresholds_") and hasattr(self, "y_thresholds_"):
+            self._build_f(self.X_thresholds_, self.y_thresholds_)
 
     def _more_tags(self):
-        return {'X_types': ['1darray']}
+        return {"X_types": ["1darray"]}
