@@ -6,29 +6,27 @@
 # License: BSD 3 clause (C) INRIA, University of Amsterdam
 from ._base import KNeighborsMixin, RadiusNeighborsMixin
 from ._base import NeighborsBase
-from ._base import UnsupervisedMixin
 from ._unsupervised import NearestNeighbors
 from ..base import TransformerMixin
-from ..utils.validation import check_is_fitted, _deprecate_positional_args
+from ..utils.validation import check_is_fitted
 
 
 def _check_params(X, metric, p, metric_params):
     """Check the validity of the input parameters"""
-    params = zip(['metric', 'p', 'metric_params'],
-                 [metric, p, metric_params])
+    params = zip(["metric", "p", "metric_params"], [metric, p, metric_params])
     est_params = X.get_params()
     for param_name, func_param in params:
         if func_param != est_params[param_name]:
             raise ValueError(
-                "Got %s for %s, while the estimator has %s for "
-                "the same parameter." % (
-                    func_param, param_name, est_params[param_name]))
+                "Got %s for %s, while the estimator has %s for the same parameter."
+                % (func_param, param_name, est_params[param_name])
+            )
 
 
 def _query_include_self(X, include_self, mode):
     """Return the query based on include_self param"""
-    if include_self == 'auto':
-        include_self = mode == 'connectivity'
+    if include_self == "auto":
+        include_self = mode == "connectivity"
 
     # it does not include each sample as its own neighbors
     if not include_self:
@@ -37,10 +35,17 @@ def _query_include_self(X, include_self, mode):
     return X
 
 
-@_deprecate_positional_args
-def kneighbors_graph(X, n_neighbors, *, mode='connectivity',
-                     metric='minkowski', p=2, metric_params=None,
-                     include_self=False, n_jobs=None):
+def kneighbors_graph(
+    X,
+    n_neighbors,
+    *,
+    mode="connectivity",
+    metric="minkowski",
+    p=2,
+    metric_params=None,
+    include_self=False,
+    n_jobs=None,
+):
     """Computes the (weighted) graph of k-Neighbors for points in X
 
     Read more in the :ref:`User Guide <unsupervised_neighbors>`.
@@ -60,10 +65,11 @@ def kneighbors_graph(X, n_neighbors, *, mode='connectivity',
         between neighbors according to the given metric.
 
     metric : str, default='minkowski'
-        The distance metric used to calculate the k-Neighbors for each sample
-        point. The DistanceMetric class gives a list of available metrics.
-        The default distance is 'euclidean' ('minkowski' metric with the p
-        param equal to 2.)
+        The distance metric to use for the tree. The default metric is
+        minkowski, and with p=2 is equivalent to the standard Euclidean
+        metric.
+        For a list of available metrics, see the documentation of
+        :class:`~sklearn.metrics.DistanceMetric`.
 
     p : int, default=2
         Power parameter for the Minkowski metric. When p = 1, this is
@@ -100,13 +106,18 @@ def kneighbors_graph(X, n_neighbors, *, mode='connectivity',
            [0., 1., 1.],
            [1., 0., 1.]])
 
-    See also
+    See Also
     --------
     radius_neighbors_graph
     """
     if not isinstance(X, KNeighborsMixin):
-        X = NearestNeighbors(n_neighbors=n_neighbors, metric=metric, p=p,
-                             metric_params=metric_params, n_jobs=n_jobs).fit(X)
+        X = NearestNeighbors(
+            n_neighbors=n_neighbors,
+            metric=metric,
+            p=p,
+            metric_params=metric_params,
+            n_jobs=n_jobs,
+        ).fit(X)
     else:
         _check_params(X, metric, p, metric_params)
 
@@ -114,10 +125,17 @@ def kneighbors_graph(X, n_neighbors, *, mode='connectivity',
     return X.kneighbors_graph(X=query, n_neighbors=n_neighbors, mode=mode)
 
 
-@_deprecate_positional_args
-def radius_neighbors_graph(X, radius, *, mode='connectivity',
-                           metric='minkowski', p=2, metric_params=None,
-                           include_self=False, n_jobs=None):
+def radius_neighbors_graph(
+    X,
+    radius,
+    *,
+    mode="connectivity",
+    metric="minkowski",
+    p=2,
+    metric_params=None,
+    include_self=False,
+    n_jobs=None,
+):
     """Computes the (weighted) graph of Neighbors for points in X
 
     Neighborhoods are restricted the points at a distance lower than
@@ -140,10 +158,11 @@ def radius_neighbors_graph(X, radius, *, mode='connectivity',
         between neighbors according to the given metric.
 
     metric : str, default='minkowski'
-        The distance metric used to calculate the neighbors within a
-        given radius for each sample point. The DistanceMetric class
-        gives a list of available metrics. The default distance is
-        'euclidean' ('minkowski' metric with the param equal to 2.)
+        The distance metric to use for the tree. The default metric is
+        minkowski, and with p=2 is equivalent to the standard Euclidean
+        metric.
+        For a list of available metrics, see the documentation of
+        :class:`~sklearn.metrics.DistanceMetric`.
 
     p : int, default=2
         Power parameter for the Minkowski metric. When p = 1, this is
@@ -181,13 +200,18 @@ def radius_neighbors_graph(X, radius, *, mode='connectivity',
            [0., 1., 0.],
            [1., 0., 1.]])
 
-    See also
+    See Also
     --------
     kneighbors_graph
     """
     if not isinstance(X, RadiusNeighborsMixin):
-        X = NearestNeighbors(radius=radius, metric=metric, p=p,
-                             metric_params=metric_params, n_jobs=n_jobs).fit(X)
+        X = NearestNeighbors(
+            radius=radius,
+            metric=metric,
+            p=p,
+            metric_params=metric_params,
+            n_jobs=n_jobs,
+        ).fit(X)
     else:
         _check_params(X, metric, p, metric_params)
 
@@ -195,9 +219,8 @@ def radius_neighbors_graph(X, radius, *, mode='connectivity',
     return X.radius_neighbors_graph(query, radius, mode)
 
 
-class KNeighborsTransformer(KNeighborsMixin, UnsupervisedMixin,
-                            TransformerMixin, NeighborsBase):
-    """Transform X into a (weighted) graph of k nearest neighbors
+class KNeighborsTransformer(KNeighborsMixin, TransformerMixin, NeighborsBase):
+    """Transform X into a (weighted) graph of k nearest neighbors.
 
     The transformed data is a sparse graph as returned by kneighbors_graph.
 
@@ -237,7 +260,7 @@ class KNeighborsTransformer(KNeighborsMixin, UnsupervisedMixin,
         nature of the problem.
 
     metric : str or callable, default='minkowski'
-        metric to use for distance computation. Any metric from scikit-learn
+        Metric to use for distance computation. Any metric from scikit-learn
         or scipy.spatial.distance can be used.
 
         If metric is a callable function, it is called on each
@@ -275,27 +298,97 @@ class KNeighborsTransformer(KNeighborsMixin, UnsupervisedMixin,
         The number of parallel jobs to run for neighbors search.
         If ``-1``, then the number of jobs is set to the number of CPU cores.
 
+    Attributes
+    ----------
+    effective_metric_ : str or callable
+        The distance metric used. It will be same as the `metric` parameter
+        or a synonym of it, e.g. 'euclidean' if the `metric` parameter set to
+        'minkowski' and `p` parameter set to 2.
+
+    effective_metric_params_ : dict
+        Additional keyword arguments for the metric function. For most metrics
+        will be same with `metric_params` parameter, but may also contain the
+        `p` parameter value if the `effective_metric_` attribute is set to
+        'minkowski'.
+
+    n_features_in_ : int
+        Number of features seen during :term:`fit`.
+
+        .. versionadded:: 0.24
+
+    feature_names_in_ : ndarray of shape (`n_features_in_`,)
+        Names of features seen during :term:`fit`. Defined only when `X`
+        has feature names that are all strings.
+
+        .. versionadded:: 1.0
+
+    n_samples_fit_ : int
+        Number of samples in the fitted data.
+
+    See Also
+    --------
+    kneighbors_graph : Compute the weighted graph of k-neighbors for
+        points in X.
+    RadiusNeighborsTransformer : Transform X into a weighted graph of
+        neighbors nearer than a radius.
+
     Examples
     --------
-    >>> from sklearn.manifold import Isomap
+    >>> from sklearn.datasets import load_wine
     >>> from sklearn.neighbors import KNeighborsTransformer
-    >>> from sklearn.pipeline import make_pipeline
-    >>> estimator = make_pipeline(
-    ...     KNeighborsTransformer(n_neighbors=5, mode='distance'),
-    ...     Isomap(neighbors_algorithm='precomputed'))
+    >>> X, _ = load_wine(return_X_y=True)
+    >>> X.shape
+    (178, 13)
+    >>> transformer = KNeighborsTransformer(n_neighbors=5, mode='distance')
+    >>> X_dist_graph = transformer.fit_transform(X)
+    >>> X_dist_graph.shape
+    (178, 178)
     """
-    @_deprecate_positional_args
-    def __init__(self, *, mode='distance', n_neighbors=5, algorithm='auto',
-                 leaf_size=30, metric='minkowski', p=2, metric_params=None,
-                 n_jobs=1):
+
+    def __init__(
+        self,
+        *,
+        mode="distance",
+        n_neighbors=5,
+        algorithm="auto",
+        leaf_size=30,
+        metric="minkowski",
+        p=2,
+        metric_params=None,
+        n_jobs=1,
+    ):
         super(KNeighborsTransformer, self).__init__(
-            n_neighbors=n_neighbors, radius=None, algorithm=algorithm,
-            leaf_size=leaf_size, metric=metric, p=p,
-            metric_params=metric_params, n_jobs=n_jobs)
+            n_neighbors=n_neighbors,
+            radius=None,
+            algorithm=algorithm,
+            leaf_size=leaf_size,
+            metric=metric,
+            p=p,
+            metric_params=metric_params,
+            n_jobs=n_jobs,
+        )
         self.mode = mode
 
+    def fit(self, X, y=None):
+        """Fit the k-nearest neighbors transformer from the training dataset.
+
+        Parameters
+        ----------
+        X : {array-like, sparse matrix} of shape (n_samples, n_features) or \
+                (n_samples, n_samples) if metric='precomputed'
+            Training data.
+        y : Ignored
+            Not used, present for API consistency by convention.
+
+        Returns
+        -------
+        self : KNeighborsTransformer
+            The fitted k-nearest neighbors transformer.
+        """
+        return self._fit(X)
+
     def transform(self, X):
-        """Computes the (weighted) graph of Neighbors for points in X
+        """Compute the (weighted) graph of Neighbors for points in X.
 
         Parameters
         ----------
@@ -311,9 +404,10 @@ class KNeighborsTransformer(KNeighborsMixin, UnsupervisedMixin,
             The matrix is of CSR format.
         """
         check_is_fitted(self)
-        add_one = self.mode == 'distance'
-        return self.kneighbors_graph(X, mode=self.mode,
-                                     n_neighbors=self.n_neighbors + add_one)
+        add_one = self.mode == "distance"
+        return self.kneighbors_graph(
+            X, mode=self.mode, n_neighbors=self.n_neighbors + add_one
+        )
 
     def fit_transform(self, X, y=None):
         """Fit to data, then transform it.
@@ -326,7 +420,8 @@ class KNeighborsTransformer(KNeighborsMixin, UnsupervisedMixin,
         X : array-like of shape (n_samples, n_features)
             Training set.
 
-        y : ignored
+        y : Ignored
+            Not used, present for API consistency by convention.
 
         Returns
         -------
@@ -338,13 +433,19 @@ class KNeighborsTransformer(KNeighborsMixin, UnsupervisedMixin,
         """
         return self.fit(X).transform(X)
 
+    def _more_tags(self):
+        return {
+            "_xfail_checks": {
+                "check_methods_sample_order_invariance": "check is not applicable."
+            }
+        }
 
-class RadiusNeighborsTransformer(RadiusNeighborsMixin, UnsupervisedMixin,
-                                 TransformerMixin, NeighborsBase):
-    """Transform X into a (weighted) graph of neighbors nearer than a radius
+
+class RadiusNeighborsTransformer(RadiusNeighborsMixin, TransformerMixin, NeighborsBase):
+    """Transform X into a (weighted) graph of neighbors nearer than a radius.
 
     The transformed data is a sparse graph as returned by
-    radius_neighbors_graph.
+    `radius_neighbors_graph`.
 
     Read more in the :ref:`User Guide <neighbors_transformer>`.
 
@@ -357,7 +458,7 @@ class RadiusNeighborsTransformer(RadiusNeighborsMixin, UnsupervisedMixin,
         matrix with ones and zeros, and 'distance' will return the distances
         between neighbors according to the given metric.
 
-    radius : float, default=1.
+    radius : float, default=1.0
         Radius of neighborhood in the transformed sparse graph.
 
     algorithm : {'auto', 'ball_tree', 'kd_tree', 'brute'}, default='auto'
@@ -379,7 +480,7 @@ class RadiusNeighborsTransformer(RadiusNeighborsMixin, UnsupervisedMixin,
         nature of the problem.
 
     metric : str or callable, default='minkowski'
-        metric to use for distance computation. Any metric from scikit-learn
+        Metric to use for distance computation. Any metric from scikit-learn
         or scipy.spatial.distance can be used.
 
         If metric is a callable function, it is called on each
@@ -417,32 +518,107 @@ class RadiusNeighborsTransformer(RadiusNeighborsMixin, UnsupervisedMixin,
         The number of parallel jobs to run for neighbors search.
         If ``-1``, then the number of jobs is set to the number of CPU cores.
 
+    Attributes
+    ----------
+    effective_metric_ : str or callable
+        The distance metric used. It will be same as the `metric` parameter
+        or a synonym of it, e.g. 'euclidean' if the `metric` parameter set to
+        'minkowski' and `p` parameter set to 2.
+
+    effective_metric_params_ : dict
+        Additional keyword arguments for the metric function. For most metrics
+        will be same with `metric_params` parameter, but may also contain the
+        `p` parameter value if the `effective_metric_` attribute is set to
+        'minkowski'.
+
+    n_features_in_ : int
+        Number of features seen during :term:`fit`.
+
+        .. versionadded:: 0.24
+
+    feature_names_in_ : ndarray of shape (`n_features_in_`,)
+        Names of features seen during :term:`fit`. Defined only when `X`
+        has feature names that are all strings.
+
+        .. versionadded:: 1.0
+
+    n_samples_fit_ : int
+        Number of samples in the fitted data.
+
+    See Also
+    --------
+    kneighbors_graph : Compute the weighted graph of k-neighbors for
+        points in X.
+    KNeighborsTransformer : Transform X into a weighted graph of k
+        nearest neighbors.
+
     Examples
     --------
+    >>> import numpy as np
+    >>> from sklearn.datasets import load_wine
     >>> from sklearn.cluster import DBSCAN
     >>> from sklearn.neighbors import RadiusNeighborsTransformer
     >>> from sklearn.pipeline import make_pipeline
+    >>> X, _ = load_wine(return_X_y=True)
     >>> estimator = make_pipeline(
     ...     RadiusNeighborsTransformer(radius=42.0, mode='distance'),
-    ...     DBSCAN(min_samples=30, metric='precomputed'))
+    ...     DBSCAN(eps=25.0, metric='precomputed'))
+    >>> X_clustered = estimator.fit_predict(X)
+    >>> clusters, counts = np.unique(X_clustered, return_counts=True)
+    >>> print(counts)
+    [ 29  15 111  11  12]
     """
-    @_deprecate_positional_args
-    def __init__(self, *, mode='distance', radius=1., algorithm='auto',
-                 leaf_size=30, metric='minkowski', p=2, metric_params=None,
-                 n_jobs=1):
+
+    def __init__(
+        self,
+        *,
+        mode="distance",
+        radius=1.0,
+        algorithm="auto",
+        leaf_size=30,
+        metric="minkowski",
+        p=2,
+        metric_params=None,
+        n_jobs=1,
+    ):
         super(RadiusNeighborsTransformer, self).__init__(
-            n_neighbors=None, radius=radius, algorithm=algorithm,
-            leaf_size=leaf_size, metric=metric, p=p,
-            metric_params=metric_params, n_jobs=n_jobs)
+            n_neighbors=None,
+            radius=radius,
+            algorithm=algorithm,
+            leaf_size=leaf_size,
+            metric=metric,
+            p=p,
+            metric_params=metric_params,
+            n_jobs=n_jobs,
+        )
         self.mode = mode
 
+    def fit(self, X, y=None):
+        """Fit the radius neighbors transformer from the training dataset.
+
+        Parameters
+        ----------
+        X : {array-like, sparse matrix} of shape (n_samples, n_features) or \
+                (n_samples, n_samples) if metric='precomputed'
+            Training data.
+
+        y : Ignored
+            Not used, present for API consistency by convention.
+
+        Returns
+        -------
+        self : RadiusNeighborsTransformer
+            The fitted radius neighbors transformer.
+        """
+        return self._fit(X)
+
     def transform(self, X):
-        """Computes the (weighted) graph of Neighbors for points in X
+        """Compute the (weighted) graph of Neighbors for points in X.
 
         Parameters
         ----------
         X : array-like of shape (n_samples_transform, n_features)
-            Sample data
+            Sample data.
 
         Returns
         -------
@@ -453,8 +629,7 @@ class RadiusNeighborsTransformer(RadiusNeighborsMixin, UnsupervisedMixin,
             The matrix is of CSR format.
         """
         check_is_fitted(self)
-        return self.radius_neighbors_graph(X, mode=self.mode,
-                                           sort_results=True)
+        return self.radius_neighbors_graph(X, mode=self.mode, sort_results=True)
 
     def fit_transform(self, X, y=None):
         """Fit to data, then transform it.
@@ -467,7 +642,8 @@ class RadiusNeighborsTransformer(RadiusNeighborsMixin, UnsupervisedMixin,
         X : array-like of shape (n_samples, n_features)
             Training set.
 
-        y : ignored
+        y : Ignored
+            Not used, present for API consistency by convention.
 
         Returns
         -------
@@ -478,3 +654,10 @@ class RadiusNeighborsTransformer(RadiusNeighborsMixin, UnsupervisedMixin,
             The matrix is of CSR format.
         """
         return self.fit(X).transform(X)
+
+    def _more_tags(self):
+        return {
+            "_xfail_checks": {
+                "check_methods_sample_order_invariance": "check is not applicable."
+            }
+        }
