@@ -1,13 +1,13 @@
 # Basic unittests to test functioning of module's top-level
 
-from sklearn.utils.testing import assert_equal
 
-__author__ = 'Yaroslav Halchenko'
-__license__ = 'BSD'
+__author__ = "Yaroslav Halchenko"
+__license__ = "BSD"
 
 
 try:
     from sklearn import *  # noqa
+
     _top_import_error = None
 except Exception as e:
     _top_import_error = e
@@ -17,4 +17,4 @@ def test_import_skl():
     # Test either above import has failed for some reason
     # "import *" is discouraged outside of the module level, hence we
     # rely on setting up the variable above
-    assert_equal(_top_import_error, None)
+    assert _top_import_error is None
